@@ -129,7 +129,16 @@ class KubeSphere(
         :param nodegroup_options: Options to create the Amazon EKS managed nodegroup. Default: - 2x m5.large on-demand instances
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KubeSphere.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                app_store: typing.Optional[builtins.bool] = None,
+                cluster: typing.Optional[aws_cdk.aws_eks.ICluster] = None,
+                nodegroup_options: typing.Optional[typing.Union[aws_cdk.aws_eks.NodegroupOptions, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KubeSphereProps(
@@ -165,7 +174,14 @@ class KubeSphereProps:
         if isinstance(nodegroup_options, dict):
             nodegroup_options = aws_cdk.aws_eks.NodegroupOptions(**nodegroup_options)
         if __debug__:
-            type_hints = typing.get_type_hints(KubeSphereProps.__init__)
+            def stub(
+                *,
+                app_store: typing.Optional[builtins.bool] = None,
+                cluster: typing.Optional[aws_cdk.aws_eks.ICluster] = None,
+                nodegroup_options: typing.Optional[typing.Union[aws_cdk.aws_eks.NodegroupOptions, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument app_store", value=app_store, expected_type=type_hints["app_store"])
             check_type(argname="argument cluster", value=cluster, expected_type=type_hints["cluster"])
             check_type(argname="argument nodegroup_options", value=nodegroup_options, expected_type=type_hints["nodegroup_options"])
